import sys

# https://gitlab.com/obviate.io/pyleglight/
import leglight

from keylight import cli, types


def _connect(host, port):
    return leglight.LegLight(host, port)


def _discover():
    lights = leglight.discover(1)
    if not lights:
        print('Could not find a Key Light', file=sys.stderr)
        exit(1)
    if len(lights) > 1:
        print(f'Found {len(lights)} Key Lights. Using the first.')
    return lights[0]


def _main(flags: types.Flags):
    light = _connect(flags.host, flags.port) if flags.host else _discover()
    print(f'Connected to: {light}')

    if flags.brightness is not None:
        print(f'Brightness: {flags.brightness}')
        light.brightness(flags.brightness)
    if flags.color is not None:
        print(f'Color: {flags.color}')
        light.color(flags.color)
    if flags.on:
        print('Turning On')
        light.on()
    if flags.off:
        print('Turning Off')
        light.off()


def main():
    _main(cli.parse())


if __name__ == '__main__':
    main()



import argparse
import sys

from keylight import constants, types


def _normalize(name: str, value: int, min: int, max: int):
    if value is None:
        return None
    if value > max:
        print(f'{name} {value} is above the maximum. Setting to {max}', file=sys.stderr)
        return max
    if value < min:
        print(f'{name} {value} is below the minimum. Setting to {min}', file=sys.stderr)
        return min
    return value


def parse() -> types.Flags:
    parser = argparse.ArgumentParser(description='A CLI to control an Elgato Key Light')
    parser.add_argument('-b', '--brightness', type=int,
                        help=f'{constants.MIN_BRIGHTNESS} <= brightness <= {constants.MAX_BRIGHTNESS}')
    parser.add_argument('-c', '--color', type=int, help='2900 <= color temperature <= 6987')
    parser.add_argument('--host', help='Hostname (without the scheme or port) of the Key Light')
    parser.add_argument('--on', action='store_true', help='Turn the Key Light on')
    parser.add_argument('--off', action='store_true', help='Turn the Key Light off')
    args = parser.parse_args()
    if args.on and args.off:
        print('--on and --off flags are mutually exclusive', file=sys.stderr)
        exit(1)
    return types.Flags(
        brightness=_normalize('Brightness', args.brightness, constants.MIN_BRIGHTNESS, constants.MAX_BRIGHTNESS),
        color=_normalize('Color', args.color, constants.MIN_COLOR, constants.MAX_COLOR),
        host=args.host,
        on=args.on,
        off=args.off,
        port=constants.DEFAULT_PORT,
    )
